from django.template import Library
from django.conf import settings
from bambu.pusher import KEY

register = Library()

@register.inclusion_tag('pusher/script.inc.html')
def pusher():
	return {
		'DEBUG': getattr(settings, 'DEBUG', False),
		'KEY': KEY
	}


from django.conf import settings
from django.utils.http import urlencode
from django.utils.timezone import now
import requests, time, hmac, hashlib, base64

__version__ = '0.0.1'

APP_ID = getattr(settings, 'PUSHER_APP_ID', None)
KEY = getattr(settings, 'PUSHER_KEY', None)
SECRET = getattr(settings, 'PUSHER_SECRET', None)
VERSION = '1.0'
DOMAIN = 'api.pusherapp.com'
PATH = '/apps/%s/events' % APP_ID

try:
	import json as simplejson
except ImportError:
	from django.utils import simplejson

def push(channel, event, **data):
	json = simplejson.dumps(
		{
			'name': event,
			'channel': channel,
			'data': simplejson.dumps(data)
		}
	)
	
	params = {
		'auth_key': KEY,
		'auth_timestamp': str(int(time.mktime(now().timetuple()))),
		'auth_version': VERSION,
		'body_md5': hashlib.md5(json).hexdigest()
	}
	
	hashparts = []
	for key in sorted(params.keys()):
		hashparts.append(
			'%s=%s' % (key, params[key])
		)
	
	msg = 'POST\n%s\n%s' % (
		PATH, '&'.join(hashparts)
	)
	
	params['auth_signature'] = hmac.new(SECRET,
		msg = msg,
		digestmod = hashlib.sha256
	).hexdigest()
	
	response = requests.post(
		'http://%s%s?%s' % (
			DOMAIN, PATH, urlencode(params)
		),
		json,
		headers = {
			'Content-Type': 'application/json'
		}
	)
	
	return response and response.status_code == 200


from bambu.pusher import KEY
from bambu.enqueue import enqueue_script_file, enqueue_script_block

def script(request):
	enqueue_script_file(request, 'https://d3dy5gmtp8yhk7.cloudfront.net/2.0/pusher.min.js')
	enqueue_script_block(request,
		"""Pusher.log = function(message) { if (window.console && window.console.log) window.console.log(message); };
		var pusher = new Pusher('%s');""" % KEY
	)


#!/usr/bin/env python
from distutils.core import setup

setup(
	name = 'bambu-pusher',
	version = '0.0.1',
	description = 'A wrapper around the Pusher API',
	author = 'Steadman',
	author_email = 'mark@steadman.io',
	url = 'http://pypi.python.org/pypi/bambu-pusher',
	install_requires = [
		'Django>=1.4',
		'requests'
	],
	packages = [
		'bambu',
		'bambu.pusher',
		'bambu.pusher.templatetags'
	],
	package_data = {
		'bambu.pusher': [
			'templates/pusher/*.html'
		]
	},
	classifiers = [
		'Development Status :: 4 - Beta',
		'Environment :: Web Environment',
		'Framework :: Django'
	]
)